@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -47,6 +47,9 @@ public abstract class AbstractResumableAbortIfNotConsumedInputStream extends Abo
     /** The key in the specified bucket under which the object is stored */
     protected final String key;
 
+    /** Whether to consume the number of bytes on invocation of {@link #skip(long)} or to delegate {@link #skip(long)} call to underlying <code>S3ObjectInputStream</code> */
+    protected final boolean consumeBytesOnSkip;
+
     private long mark;
 
     /**
@@ -55,13 +58,15 @@ public abstract class AbstractResumableAbortIfNotConsumedInputStream extends Abo
      * @param objectContent The input stream containing the contents of an object
      * @param bucketName The name of the bucket containing the desired object
      * @param key The key in the specified bucket under which the object is stored
+     * @param consumeBytesOnSkip <code>true</code> to consume the number of bytes on invocation of {@link #skip(long)}; otherwise <code>false</code> to delegate {@link #skip(long)} call to underlying <code>S3ObjectInputStream</code>
      * @param s3Client The S3 client
      */
-    protected AbstractResumableAbortIfNotConsumedInputStream(S3ObjectInputStream objectContent, String bucketName, String key, AmazonS3Client s3Client) {
+    protected AbstractResumableAbortIfNotConsumedInputStream(S3ObjectInputStream objectContent, String bucketName, String key, boolean consumeBytesOnSkip, AmazonS3Client s3Client) {
         super(objectContent);
         this.bucketName = bucketName;
         this.key = key;
         this.s3Client = s3Client;
+        this.consumeBytesOnSkip = consumeBytesOnSkip;
         mark = -1;
     }
 
@@ -134,16 +139,16 @@ public abstract class AbstractResumableAbortIfNotConsumedInputStream extends Abo
     }
 
     @Override
-    public int read(byte b[]) throws IOException {
+    public int read(byte[] b) throws IOException {
         return read(b, 0, b.length);
     }
 
     @Override
-    public int read(byte b[], int off, int len) throws IOException {
+    public int read(byte[] b, int off, int len) throws IOException {
         return doRead(b, off, len, false);
     }
 
-    private int doRead(byte b[], int off, int len, boolean errorOnPrematureEof) throws IOException {
+    private int doRead(byte[] b, int off, int len, boolean errorOnPrematureEof) throws IOException {
         try {
             int result = objectContent.read(b, off, len);
             if (result >= 0) {
@@ -160,6 +165,19 @@ public abstract class AbstractResumableAbortIfNotConsumedInputStream extends Abo
 
     @Override
     public long skip(long n) throws IOException {
+        if (consumeBytesOnSkip) {
+            long bytesToSkip = n;
+            int buflen = (int) Math.min(8192, bytesToSkip);
+            byte[] buffer = new byte[buflen];
+            long result = 0;
+            for (int read; bytesToSkip > 0 && (read = objectContent.read(buffer, 0, (int) Math.min(buflen, bytesToSkip))) > 0;) {
+                result += read;
+                bytesToSkip -= read;
+            }
+            onBytesRead(result);
+            return result;
+        }
+
         long result = objectContent.skip(n);
         onBytesRead(result);
         return result;
@@ -205,7 +223,12 @@ public abstract class AbstractResumableAbortIfNotConsumedInputStream extends Abo
      * @return <code>true</code> if premature EOF; otherwise <code>false</code>
      */
     protected static boolean isPrematureEof(IOException e) {
-        if ("org.apache.http.ConnectionClosedException".equals(e.getClass().getName())) {
+        if (e instanceof java.net.SocketException && "Connection reset".equals(e.getMessage())) {
+            // The S3 end-point has deliberately reset the connection
+            return true;
+        }
+
+        if (e instanceof org.apache.http.ConnectionClosedException) {
             // HTTP connection has been closed unexpectedly
             String message = e.getMessage();
             if (message != null && message.startsWith("Premature end of Content-Length delimited message body")) {
@@ -237,7 +260,7 @@ public abstract class AbstractResumableAbortIfNotConsumedInputStream extends Abo
      * @return The appropriate I/O exception
      */
     protected static IOException wrap(AmazonClientException e, String key) {
-        if (AmazonServiceException.class.isInstance(e)) {
+        if ((e instanceof AmazonServiceException)) {
             AmazonServiceException serviceError = (AmazonServiceException) e;
             /*
              * Map to appropriate FileStorageCodes if possible
