@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -46,10 +46,11 @@ public class RangeAcceptingResumableAbortIfNotConsumedInputStream extends Abstra
      * @param range The optional range
      * @param bucketName The name of the bucket containing the desired object
      * @param key The key in the specified bucket under which the object is stored
+     * @param consumeBytesOnSkip <code>true</code> to consume the number of bytes on invocation of {@link #skip(long)}; otherwise <code>false</code> to delegate {@link #skip(long)} call to underlying <code>S3ObjectInputStream</code>
      * @param s3Client The S3 client
      */
-    public RangeAcceptingResumableAbortIfNotConsumedInputStream(S3ObjectInputStream objectContent, long[] range, String bucketName, String key, AmazonS3Client s3Client) {
-        super(objectContent, bucketName, key, s3Client);
+    public RangeAcceptingResumableAbortIfNotConsumedInputStream(S3ObjectInputStream objectContent, long[] range, String bucketName, String key, boolean consumeBytesOnSkip, AmazonS3Client s3Client) {
+        super(objectContent, bucketName, key, consumeBytesOnSkip, s3Client);
         rangeEnd = range[1];
         rangeStart = range[0];
     }
@@ -75,7 +76,7 @@ public class RangeAcceptingResumableAbortIfNotConsumedInputStream extends Abstra
         try {
             GetObjectRequest request = new GetObjectRequest(bucketName, key);
             request.setRange(rangeStart, rangeEnd);
-            objectContent = s3Client.getObject(request).getObjectContent();
+            objectContent = new RetryingS3OperationExecutor<S3ObjectInputStream>(c -> c.getObject(request).getObjectContent(), 3).execute(s3Client);
         } catch (AmazonClientException ce) {
             throw wrap(ce, key);
         }
