@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -48,10 +48,11 @@ public class ResumableAbortIfNotConsumedInputStream extends AbstractResumableAbo
      * @param objectContent The input stream containing the contents of an object
      * @param bucketName The name of the bucket containing the desired object
      * @param key The key in the specified bucket under which the object is stored
+     * @param consumeBytesOnSkip <code>true</code> to consume the number of bytes on invocation of {@link #skip(long)}; otherwise <code>false</code> to delegate {@link #skip(long)} call to underlying <code>S3ObjectInputStream</code>
      * @param s3Client The S3 client
      */
-    public ResumableAbortIfNotConsumedInputStream(S3ObjectInputStream objectContent, String bucketName, String key, AmazonS3Client s3Client) {
-        super(objectContent, bucketName, key, s3Client);
+    public ResumableAbortIfNotConsumedInputStream(S3ObjectInputStream objectContent, String bucketName, String key, boolean consumeBytesOnSkip, AmazonS3Client s3Client) {
+        super(objectContent, bucketName, key, consumeBytesOnSkip, s3Client);
         numberOfReadBytes = 0;
         contentLength = -1;
     }
@@ -79,7 +80,7 @@ public class ResumableAbortIfNotConsumedInputStream extends AbstractResumableAbo
             long rangeStart = numberOfReadBytes;
             GetObjectRequest request = new GetObjectRequest(bucketName, key);
             request.setRange(rangeStart, rangeEnd);
-            objectContent = s3Client.getObject(request).getObjectContent();
+            objectContent = new RetryingS3OperationExecutor<S3ObjectInputStream>(c -> c.getObject(request).getObjectContent(), 3).execute(s3Client);
         } catch (AmazonClientException ce) {
             throw wrap(ce, key);
         }
@@ -117,7 +118,7 @@ public class ResumableAbortIfNotConsumedInputStream extends AbstractResumableAbo
      */
     private S3Object getObject() throws IOException {
         try {
-            return s3Client.getObject(bucketName, key);
+            return new RetryingS3OperationExecutor<S3Object>(c -> c.getObject(bucketName, key), 3).execute(s3Client);
         } catch (AmazonClientException e) {
             throw wrap(e, key);
         }
