@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -392,6 +392,22 @@ public enum S3ExceptionCode implements DisplayableOXExceptionCode {
      * Failed to create a bucket for name "%1$s" using region "%2$s"
      */
     BUCKET_CREATION_FAILED(S3ExceptionMessages.BUCKET_CREATION_FAILED, CATEGORY_CONFIGURATION, 81),
+    /**
+     * An SQL error occurred: %1$s
+     */
+    SQL_ERROR("An SQL error occurred: %1$s", CATEGORY_ERROR, 82),
+    /**
+     * No such document: %1$s
+     */
+    NO_SUCH_DOCUMENT("No such document: %1$s", CATEGORY_ERROR, 83),
+    /**
+     * No such chunk: %1$s
+     */
+    NO_SUCH_CHUNK("No such chunk: %1$s", CATEGORY_ERROR, 84),
+    /**
+     * No next chunk for chunk: %1$s
+     */
+    NO_NEXT_CHUNK("No next chunk for chunk: %1$s", CATEGORY_ERROR, 85),
 
     ;
 
@@ -514,7 +530,7 @@ public enum S3ExceptionCode implements DisplayableOXExceptionCode {
      * @return The wrapping error code
      */
     public static OXException wrap(final AmazonClientException e, String key) {
-        if (AmazonServiceException.class.isInstance(e)) {
+        if ((e instanceof AmazonServiceException)) {
             final AmazonServiceException serviceError = (AmazonServiceException) e;
             /*
              * Map to appropriate FileStorageCodes if possible
@@ -526,7 +542,7 @@ public enum S3ExceptionCode implements DisplayableOXExceptionCode {
             final String errorCode = serviceError.getErrorCode();
             final S3ExceptionCode code = S3ExceptionCode.getCodeFor(errorCode);
             if (null != code) {
-                return code.create(e, new Object[0]);
+                return code.create(e);
             }
         }
         return FileStorageCodes.IOERROR.create(e, e.getMessage());
@@ -590,7 +606,7 @@ public enum S3ExceptionCode implements DisplayableOXExceptionCode {
      * @return The newly created {@link OXException} instance
      */
     public OXException create() {
-        return OXExceptionFactory.getInstance().create(this, new Object[0]);
+        return OXExceptionFactory.getInstance().create(this);
     }
 
     /**
