@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -64,7 +64,7 @@ public class ETagCorrectionHandler extends RequestHandler2 {
     @Override
     public void afterResponse(Request<?> request, Response<?> response) {
         Object awsResponse = response.getAwsResponse();
-        if (ObjectMetadata.class.isInstance(awsResponse)) {
+        if ((awsResponse instanceof ObjectMetadata)) {
             ObjectMetadata metadata = (ObjectMetadata) awsResponse;
             Map<String, Object> headers = metadata.getRawMetadata();
             if (null != headers) {
