@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,6 +21,8 @@
 
 package com.openexchange.filestore.s3.internal.client;
 
+import static com.amazonaws.SDKGlobalConfiguration.AWS_ROLE_ARN_ENV_VAR;
+import static com.amazonaws.SDKGlobalConfiguration.AWS_WEB_IDENTITY_ENV_VAR;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
@@ -36,14 +38,18 @@ import java.security.cert.Certificate;
 import java.security.cert.CertificateException;
 import java.util.Arrays;
 import java.util.Enumeration;
+import org.apache.http.conn.ssl.NoopHostnameVerifier;
+import org.apache.http.conn.ssl.SSLConnectionSocketFactory;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import com.amazonaws.ApacheHttpClientConfig;
 import com.amazonaws.ClientConfiguration;
 import com.amazonaws.auth.AWSCredentials;
 import com.amazonaws.auth.AWSCredentialsProvider;
 import com.amazonaws.auth.AWSStaticCredentialsProvider;
 import com.amazonaws.auth.BasicAWSCredentials;
 import com.amazonaws.auth.InstanceProfileCredentialsProvider;
+import com.amazonaws.auth.WebIdentityTokenCredentialsProvider;
 import com.amazonaws.client.builder.AwsClientBuilder.EndpointConfiguration;
 import com.amazonaws.regions.Regions;
 import com.amazonaws.services.s3.AmazonS3Builder;
@@ -65,6 +71,8 @@ import com.openexchange.filestore.s3.internal.config.S3EncryptionConfig;
 import com.openexchange.filestore.s3.metrics.PerClientMetricCollector;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
+import com.openexchange.net.ssl.SSLSocketFactoryProvider;
+import com.openexchange.net.ssl.config.SSLConfigurationService;
 import com.openexchange.systemproperties.SystemPropertiesUtils;
 
 /**
@@ -73,7 +81,14 @@ import com.openexchange.systemproperties.SystemPropertiesUtils;
  * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
  * @since v7.10.4
  */
-public class S3ClientFactory {
+public final class S3ClientFactory {
+
+    /**
+     * Initializes a new {@link S3ClientFactory}.
+     */
+    private S3ClientFactory() {
+        super();
+    }
 
     private static final Logger LOG = LoggerFactory.getLogger(S3ClientFactory.class);
 
@@ -84,7 +99,7 @@ public class S3ClientFactory {
      * @return The {@link AmazonS3Client}
      * @throws OXException
      */
-    public S3FileStorageClient initS3Client(S3ClientConfig clientConfig) throws OXException {
+    public static S3FileStorageClient initS3Client(S3ClientConfig clientConfig) throws OXException {
         /*
          * prepare credentials provider
          */
@@ -101,7 +116,13 @@ public class S3ClientFactory {
                 credentialsSource = S3CredentialsSource.STATIC;
             }
             if (S3CredentialsSource.IAM == credentialsSource) {
-                credentialsProvider = InstanceProfileCredentialsProvider.getInstance();
+                String webIdentityTokenFile = System.getenv(AWS_WEB_IDENTITY_ENV_VAR);
+                String roleArn = System.getenv(AWS_ROLE_ARN_ENV_VAR);
+                if (Strings.isNotEmpty(webIdentityTokenFile) && Strings.isNotEmpty(roleArn)) {
+                    credentialsProvider = WebIdentityTokenCredentialsProvider.builder().roleArn(roleArn).webIdentityTokenFile(webIdentityTokenFile).build();
+                } else {
+                    credentialsProvider = InstanceProfileCredentialsProvider.getInstance();
+                }
             } else {
                 String accessKey = clientConfig.getValueSafe(S3ClientProperty.ACCESS_KEY);
                 String secretKey = clientConfig.getValueSafe(S3ClientProperty.SECRET_KEY);
@@ -147,7 +168,7 @@ public class S3ClientFactory {
         }
         String pathStyleAccess = clientConfig.getValue(S3ClientProperty.PATH_STYLE_ACCESS);
         clientBuilder.setPathStyleAccessEnabled(Boolean.valueOf(pathStyleAccess));
-        clientBuilder.withRequestHandlers(ETagCorrectionHandler.getInstance());
+        clientBuilder.withRequestHandlers(ETagCorrectionHandler.getInstance(), HeaderCorrectionHandler.getInstance());
 
         if (isMetricsEnabled(clientConfig)) {
             clientBuilder.setMetricsCollector(new PerClientMetricCollector(clientConfig));
@@ -161,7 +182,14 @@ public class S3ClientFactory {
             throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, chunkSizeProperty);
         }
         String key = clientConfig.getClientID().orElse(clientConfig.getFilestoreID());
-        return new S3FileStorageClient(key, (AmazonS3Client) clientBuilder.build(), encryptionConfig, chunkSize, clientConfig.getClientScope(), clientConfig.getFingerprint());
+        boolean uploadPartCopy = Boolean.parseBoolean(clientConfig.getValue(S3ClientProperty.UPLOAD_PART_COPY));
+        int numOfRetryAttemptsOnConnectionPoolTimeout;
+        try {
+            numOfRetryAttemptsOnConnectionPoolTimeout = Integer.parseInt(clientConfig.getValue(S3ClientProperty.NUM_OF_RETRIES_ON_CONNECTION_POOL_TIMEOUT));
+        } catch (NumberFormatException e) {
+            numOfRetryAttemptsOnConnectionPoolTimeout = 0;
+        }
+        return new S3FileStorageClient(key, (AmazonS3Client) clientBuilder.build(), encryptionConfig, chunkSize, clientConfig.getClientScope(), clientConfig.getFingerprint(), uploadPartCopy, numOfRetryAttemptsOnConnectionPoolTimeout);
     }
 
     /**
@@ -170,7 +198,7 @@ public class S3ClientFactory {
      * @param clientConfig The client config
      * @return <code>true</code> if metrics shall be collected
      */
-    private boolean isMetricsEnabled(S3ClientConfig clientConfig) {
+    private static boolean isMetricsEnabled(S3ClientConfig clientConfig) {
         return clientConfig.getClientScope().isShared()
                && clientConfig.enableMetricCollection()
                && clientConfig.getNumberOfConfiguredClients() <= clientConfig.getMaxNumberOfMonitoredClients();
@@ -184,8 +212,8 @@ public class S3ClientFactory {
      * @return The {@link EncryptionMaterials}
      * @throws OXException in case of errors or if the client encryption type is not applicable
      */
-    private EncryptionMaterials getEncryptionMaterials(S3ClientConfig clientConfig, EncryptionType clientEncryptionType) throws OXException {
-        if (!EncryptionType.RSA.equals(clientEncryptionType)) {
+    private static EncryptionMaterials getEncryptionMaterials(S3ClientConfig clientConfig, EncryptionType clientEncryptionType) throws OXException {
+        if (EncryptionType.RSA != clientEncryptionType) {
             throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("Unsupported encryption type: " + clientEncryptionType.getName());
         }
         String keyStore = clientConfig.getValueSafe(S3ClientProperty.RSA_KEYSTORE);
@@ -223,17 +251,7 @@ public class S3ClientFactory {
                     }
                 }
             }
-        } catch (FileNotFoundException e) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
-        } catch (KeyStoreException e) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
-        } catch (NoSuchAlgorithmException e) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
-        } catch (CertificateException e) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
-        } catch (IOException e) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
-        } catch (UnrecoverableKeyException e) {
+        } catch (Exception e) {
             throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
         } finally {
             Streams.close(inputStream);
@@ -252,10 +270,19 @@ public class S3ClientFactory {
      *
      * @param clientConfig The client config
      * @return An according {@link ClientConfiguration} instance
+     * @throws OXException If required services are absent
      */
-    private ClientConfiguration getClientConfiguration(S3ClientConfig clientConfig) {
+    private static ClientConfiguration getClientConfiguration(S3ClientConfig clientConfig) throws OXException {
+        SSLSocketFactoryProvider factoryProvider = clientConfig.getServices().getServiceSafe(SSLSocketFactoryProvider.class);
+        SSLConfigurationService sslConfig = clientConfig.getServices().getServiceSafe(SSLConfigurationService.class);
+
         ClientConfiguration clientConfiguration = new ClientConfiguration();
 
+        {
+            ApacheHttpClientConfig apacheHttpClientConfig = clientConfiguration.getApacheHttpClientConfig();
+            apacheHttpClientConfig.setSslSocketFactory(new SSLConnectionSocketFactory(factoryProvider.getDefault(), sslConfig.getSupportedProtocols(), sslConfig.getSupportedCipherSuites(), NoopHostnameVerifier.INSTANCE));
+        }
+
         {
             String signerOverride = clientConfig.getValue(S3ClientProperty.SIGNER_OVERRIDE);
             if (Strings.isNotEmpty(signerOverride)) {
@@ -311,6 +338,18 @@ public class S3ClientFactory {
             }
         }
 
+        {
+            ConfigProperty maxConnectionPoolSize = clientConfig.getProperty(S3ClientProperty.MAX_CONNECTION_POOL_SIZE);
+            if (Strings.isNotEmpty(maxConnectionPoolSize.getValue())) {
+                try {
+                    clientConfiguration.setMaxConnections(Integer.parseInt(maxConnectionPoolSize.getValue().trim()));
+                } catch (NumberFormatException e) {
+                    // Invalid connect timeout.
+                    LOG.warn("Invalid integer value specified for {}", maxConnectionPoolSize.getKey(), e);
+                }
+            }
+        }
+
         String proxyHost = SystemPropertiesUtils.getProperty("http.proxyHost");
         if (proxyHost != null) {
             clientConfiguration.setProxyHost(proxyHost);
