@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -56,19 +56,16 @@ public class S3ClientRegistry implements Reloadable {
         static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(S3ClientRegistry.class);
     }
 
-    private final S3ClientFactory clientFactory;
     private final ServiceLookup services;
     private final Cache<String, S3FileStorageClient> clients;
 
     /**
      * Initializes a new {@link S3ClientRegistry}.
      *
-     * @param clientFactory The client factory
      * @param services The {@link ServiceLookup} containing a {@link LeanConfigurationService}
      */
-    public S3ClientRegistry(S3ClientFactory clientFactory, ServiceLookup services) {
+    public S3ClientRegistry(ServiceLookup services) {
         super();
-        this.clientFactory = clientFactory;
         this.services = services;
         clients = CacheBuilder.newBuilder()
             .weakValues()
@@ -113,7 +110,7 @@ public class S3ClientRegistry implements Reloadable {
     }
 
     private Callable<? extends S3FileStorageClient> createLoaderFor(S3ClientConfig clientConfig) {
-        return new S3ClientLoaderCallable(clientConfig, this.clientFactory);
+        return new S3ClientLoaderCallable(clientConfig);
     }
 
     @Override
@@ -125,7 +122,7 @@ public class S3ClientRegistry implements Reloadable {
     }
 
     @Override
-    public void reloadConfiguration(ConfigurationService _unused) {
+    public void reloadConfiguration(ConfigurationService notUsed) {
         try {
             LeanConfigurationService configService = services.getServiceSafe(LeanConfigurationService.class);
             List<S3FileStorageClient> toRemove = new LinkedList<>();
@@ -151,16 +148,14 @@ public class S3ClientRegistry implements Reloadable {
     private static class S3ClientLoaderCallable implements Callable<S3FileStorageClient> {
 
         private final S3ClientConfig clientConfig;
-        private final S3ClientFactory clientFactory;
 
-        S3ClientLoaderCallable(S3ClientConfig clientConfig, S3ClientFactory clientFactory) {
+        S3ClientLoaderCallable(S3ClientConfig clientConfig) {
             this.clientConfig = clientConfig;
-            this.clientFactory = clientFactory;
         }
 
         @Override
         public S3FileStorageClient call() throws Exception {
-            return clientFactory.initS3Client(clientConfig);
+            return S3ClientFactory.initS3Client(clientConfig);
         }
     }
 
