@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -43,6 +43,8 @@ public class S3FileStorageClient {
     private final long chunkSize;
     private final S3ClientScope scope;
     private final int configFingerprint;
+    private final boolean useUploadPartCopy;
+    private final int numOfRetryAttemptsOnConnectionPoolTimeout;
 
     /**
      * Initializes a new {@link S3FileStorageClient}.
@@ -53,8 +55,9 @@ public class S3FileStorageClient {
      * @param chunkSize The chunk size
      * @param scope The client scope
      * @param configFingerprint The config fingerprint at the time of this clients creation
+     * @param numOfRetryAttemptsOnConnectionPoolTimeout The number of retry attempts if a timeout happens while waiting for an available connection from a connection manager
      */
-    S3FileStorageClient(String key, AmazonS3Client client, S3EncryptionConfig encryptionConfig, long chunkSize, S3ClientScope scope, int configFingerprint) {
+    S3FileStorageClient(String key, AmazonS3Client client, S3EncryptionConfig encryptionConfig, long chunkSize, S3ClientScope scope, int configFingerprint, boolean useUploadPartCopy, int numOfRetryAttemptsOnConnectionPoolTimeout) {
         super();
         this.key = key;
         this.client = client;
@@ -62,6 +65,17 @@ public class S3FileStorageClient {
         this.chunkSize = chunkSize;
         this.scope = scope;
         this.configFingerprint = configFingerprint;
+        this.useUploadPartCopy = useUploadPartCopy;
+        this.numOfRetryAttemptsOnConnectionPoolTimeout = numOfRetryAttemptsOnConnectionPoolTimeout;
+    }
+
+    /**
+     * Gets the number of retry attempts if a timeout happens while waiting for an available connection from a connection manager.
+     *
+     * @return The number of retry attempts
+     */
+    public int getNumOfRetryAttemptsOnConnectionPoolTimeout() {
+        return numOfRetryAttemptsOnConnectionPoolTimeout;
     }
 
     /**
@@ -100,6 +114,15 @@ public class S3FileStorageClient {
         return chunkSize;
     }
 
+    /**
+     * Returns whether to use "UploadPartCopy" requests
+     *
+     * @return <code>True</code> to  use "UploadPartCopy", <code>false</code> otherwise
+     */
+    public boolean useUploadPartCopy() {
+        return useUploadPartCopy;
+    }
+
     /**
      * Gets the client scope
      *
