@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -39,6 +39,7 @@ import com.openexchange.config.lean.Property;
 import com.openexchange.configuration.ConfigurationExceptionCodes;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Strings;
+import com.openexchange.server.ServiceLookup;
 
 /**
  * {@link S3ClientConfig}
@@ -48,34 +49,49 @@ import com.openexchange.java.Strings;
  */
 public class S3ClientConfig {
 
+    /**
+     * Initializes a new {@link S3ClientConfig}
+     *
+     * @param filestoreID The file storage identifier
+     * @param services The service look-up
+     * @return The {@link S3ClientConfig}
+     * @throws OXException
+     */
+    public static S3ClientConfig init(String filestoreID, ServiceLookup services) throws OXException {
+        LeanConfigurationService configService = services.getServiceSafe(LeanConfigurationService.class);
+        return new S3ClientConfig(filestoreID, getBucketAndClientInfo(filestoreID, configService), services);
+    }
+
+    // -------------------------------------------------------------------------------------------------------------------------------------
+
     private final String filestoreID;
     private final BucketAndClientInfo bucketAndClientInfo;
     private final LeanConfigurationService configService;
+    private final ServiceLookup services;
 
     /**
      * Initializes a new {@link S3ClientConfig}.
      *
-     * @param filestoreID The filestore id
-     * @param bucketAndClientInfo The {@link BucketAndClientInfo}
-     * @param configService The {@link LeanConfigurationService}
+     * @param filestoreID The file storage identifier
+     * @param bucketAndClientInfo The service look-up
+     * @param services The service look-up
+     * @throws OXException If initialization fails
      */
-    private S3ClientConfig(String filestoreID, BucketAndClientInfo bucketAndClientInfo, LeanConfigurationService configService) {
+    private S3ClientConfig(String filestoreID, BucketAndClientInfo bucketAndClientInfo, ServiceLookup services) throws OXException {
         super();
         this.filestoreID = filestoreID;
         this.bucketAndClientInfo = bucketAndClientInfo;
-        this.configService = configService;
+        this.services = services;
+        configService = services.getServiceSafe(LeanConfigurationService.class);
     }
 
     /**
-     * Initializes a new {@link S3ClientConfig}
+     * Gets the service look-up providing tracked services.
      *
-     * @param filestoreID The filestore id
-     * @param configService The {@link LeanConfigurationService}
-     * @return The {@link S3ClientConfig}
-     * @throws OXException
+     * @return The service look-up
      */
-    public static S3ClientConfig init(String filestoreID, LeanConfigurationService configService) throws OXException {
-        return new S3ClientConfig(filestoreID, getBucketAndClientInfo(filestoreID, configService), configService);
+    public ServiceLookup getServices() {
+        return services;
     }
 
     /**
@@ -241,6 +257,8 @@ public class S3ClientConfig {
 
     /**
      * Gets the number of currently configured clients.
+     *
+     * @return The number of currently configured clients
      */
     public int getNumberOfConfiguredClients() {
         Map<String, String> s3ClientProperties = configService.getProperties((k, v) -> k.startsWith(S3ClientProperty.PREFIX));
@@ -252,6 +270,8 @@ public class S3ClientConfig {
 
     /**
      * Gets the max. number of clients that might be configured to have per-client monitoring enabled.
+     *
+     * @return The max. number of clients
      */
     public int getMaxNumberOfMonitoredClients() {
         return configService.getIntProperty(S3Property.MAX_NUMBER_OF_MONITORED_CLIENTS);
@@ -259,6 +279,8 @@ public class S3ClientConfig {
 
     /**
      * Gets whether metric collection is enabled.
+     *
+     * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean enableMetricCollection() {
         return configService.getBooleanProperty(S3Property.METRIC_COLLECTION);
@@ -310,13 +332,15 @@ public class S3ClientConfig {
         return Collections.singletonMap(S3ClientProperty.QUALIFIER_CLIENT_ID, clientID.get());
     }
 
+    private static final Pattern PATTERN_SPLIT_BY_COMMA = Pattern.compile("\\s*,\\s*");
+
     /**
      * Gets the bucket and client info
      *
-     * @param filestoreID The filestore id
-     * @param configService The {@link LeanConfigurationService}
+     * @param filestoreID The file storage identifier
+     * @param configService The service to use
      * @return The {@link BucketAndClientInfo}
-     * @throws OXException
+     * @throws OXException If bucket/client cannot be returned
      */
     private static BucketAndClientInfo getBucketAndClientInfo(String filestoreID, LeanConfigurationService configService) throws OXException {
         // look for full-qualified property 'com.openexchange.filestore.s3.[filestoreID].bucketName'
@@ -334,11 +358,11 @@ public class S3ClientConfig {
                     e -> e.getValue()));
 
             Optional<Entry<String, String>> optEntry = clientIDsToBuckets.entrySet().parallelStream()
-                                                                                    .filter((e) -> Pattern.compile("\\s*,\\s*")
+                                                                                    .filter((e) -> PATTERN_SPLIT_BY_COMMA
                                                                                                           .splitAsStream(e.getValue())
                                                                                                           .anyMatch((bn) -> isBucketNameMatch(bn, assumedBucketName)))
                                                                                     .findFirst();
-            if(optEntry.isPresent()) {
+            if (optEntry.isPresent()) {
                 bucketName = assumedBucketName;
                 clientID = Optional.of(optEntry.get().getKey());
             }
@@ -348,12 +372,11 @@ public class S3ClientConfig {
             throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("No bucket name was found for filestore '" + filestoreID + "'");
         }
 
-        BucketAndClientInfo info = new BucketAndClientInfo(clientID, bucketName);
-        return info;
+        return new BucketAndClientInfo(clientID, bucketName);
     }
 
     /**
-     * Checks if the given bucketname matches the bucketNamePattern
+     * Checks if the given bucket name matches the bucket name pattern
      *
      * @param bucketNamePattern The configured bucket name pattern to match the name against
      * @param bucketName The bucket name to match
@@ -432,7 +455,6 @@ public class S3ClientConfig {
         public String toString() {
             return key + "=" + value;
         }
-
     }
 
     /**
@@ -446,35 +468,32 @@ public class S3ClientConfig {
         /**
          * Initializes a new {@link BucketAndClientInfo}.
          *
-         * @param clientID The client id
+         * @param clientID The optional client identifier
          * @param bucketName The bucket name
          */
-        public BucketAndClientInfo(Optional<String> clientID, String bucketName) {
+        BucketAndClientInfo(Optional<String> clientID, String bucketName) {
             super();
             this.clientID = clientID;
             this.bucketName = bucketName;
         }
 
-
         /**
-         * Gets the clientID
+         * Gets the optional client identifier
          *
-         * @return The clientID
+         * @return The optional client identifier
          */
-        public Optional<String> getClientID() {
+        Optional<String> getClientID() {
             return clientID;
         }
 
-
         /**
-         * Gets the bucketName
+         * Gets the bucket name
          *
-         * @return The bucketName
+         * @return The bucket name
          */
-        public String getBucketName() {
+        String getBucketName() {
             return bucketName;
         }
-
     }
 
 }
