@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -63,7 +63,7 @@ public enum S3ClientProperty implements Property {
     /**
      * "com.openexchange.filestore.s3client.[clientID].chunkSize"
      */
-    CHUNK_SIZE("chunkSize", "5 MB"),
+    CHUNK_SIZE("chunkSize", "64 MB"),
     /**
      * "com.openexchange.filestore.s3client.[clientID].encryption.rsa.keyStore"
      */
@@ -96,6 +96,27 @@ public enum S3ClientProperty implements Property {
      * "com.openexchange.filestore.s3client.[clientID].maxRetries"
      */
     MAX_RETRIES("maxRetries", "3"),
+    /**
+     * "com.openexchange.filestore.s3client.[clientID].uploadPartCopy"
+     * <p/>
+     * Configures whether the <code>CopyPartRequest</code> operation should be used or not, which improves <i>append</i> operations to
+     * existing files by copying over the original data directly on S3, prior uploading the remaining data within a multipart upload.
+     * <p/>
+     * Otherwise, the <i>append</i> operation is performed by streaming the original data through the middleware to the S3, concatenated
+     * with the new data.
+     * <p/>
+     * <code>CopyPartRequest</code> might not be available on all S3 implemenations, and cannot be used if client-side encryption is
+     * enabled due to cryptographic constraints.
+     */
+    UPLOAD_PART_COPY("uploadPartCopy", Boolean.TRUE),
+    /**
+     * "com.openexchange.filestore.s3client.[clientID].numOfRetriesOnConnectionPoolTimeout"
+     * <p>
+     * Sets the number of retry attempts if a timeout happens while waiting for an available connection from a connection manager.
+     * <p>
+     * E.g. an instance of <code>"org.apache.http.conn.ConnectionPoolTimeoutException"</code> is thrown.
+     */
+    NUM_OF_RETRIES_ON_CONNECTION_POOL_TIMEOUT("numOfRetriesOnConnectionPoolTimeout", "0"),
     ;
 
     public static final String PREFIX = "com.openexchange.filestore.s3client.";
