@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -109,7 +109,19 @@ public enum S3Property implements Property {
      * com.openexchange.filestore.s3.maxNumberOfMonitoredClients
      */
     MAX_NUMBER_OF_MONITORED_CLIENTS("com.openexchange.filestore.s3.", "maxNumberOfMonitoredClients", I(20)),
-
+    /**
+     * "com.openexchange.filestore.s3.[filestoreID].uploadPartCopy"
+     * <p/>
+     * Configures whether the <code>CopyPartRequest</code> operation should be used or not, which improves <i>append</i> operations to
+     * existing files by copying over the original data directly on S3, prior uploading the remaining data within a multipart upload.
+     * <p/>
+     * Otherwise, the <i>append</i> operation is performed by streaming the original data through the middleware to the S3, concatenated
+     * with the new data.
+     * <p/>
+     * <code>CopyPartRequest</code> might not be available on all S3 implemenations, and cannot be used if client-side encryption is
+     * enabled due to cryptographic constraints.
+     */
+    UPLOAD_PART_COPY(S3ClientProperty.UPLOAD_PART_COPY),
     ;
 
     public static final String OPTIONAL_NAME = "filestoreID";
