@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -70,7 +70,7 @@ public class PerClientMetricCollector extends RequestMetricCollector {
         String maxConnectionPoolSize = clientConfig.getValue(S3ClientProperty.MAX_CONNECTION_POOL_SIZE);
         if (Strings.isNotEmpty(maxConnectionPoolSize)) {
             try {
-                maxConnections = new Integer(maxConnectionPoolSize.trim()).doubleValue();
+                maxConnections = Integer.valueOf(maxConnectionPoolSize.trim()).doubleValue();
             } catch (@SuppressWarnings("unused") NumberFormatException e) {
                 // ignore
             }
@@ -134,12 +134,10 @@ public class PerClientMetricCollector extends RequestMetricCollector {
             AtomicReference<Double> ref = poolStatsCounters.get(field);
             Number counter = ti.getCounter(field.name());
             if (counter != null && counter.doubleValue() >= 0.0d) {
-                ref.set(new Double(counter.doubleValue()));
+                ref.set(Double.valueOf(counter.doubleValue()));
             }
         }
 
-        // ServiceName=[Amazon S3], StatusCode=[200], ServiceEndpoint=[https://st-files-2-push.s3.eu-central-1.amazonaws.com], RequestType=[GetObjectMetadataRequest], AWSRequestID=[3A7F314BC82CD57A], HttpClientPoolPendingCount=0, RetryCapacityConsumed=0, HttpClientPoolAvailableCount=1, RequestCount=1, HttpClientPoolLeasedCount=0, ResponseProcessingTime=[8.717], ClientExecuteTime=[25.678], HttpClientSendRequestTime=[0.251], HttpRequestTime=[16.294], RequestSigningTime=[0.183], CredentialsRequestTime=[0.002, 0.001], HttpClientReceiveResponseTime=[15.52],
-
         String requestType = "UNKNOWN";
         List<Object> property = m.getProperty(Field.RequestType);
         if (property != null && property.isEmpty() == false) {
