@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,13 +22,24 @@
 package com.openexchange.filestore.s3.osgi;
 
 import com.amazonaws.metrics.AwsSdkMetrics;
+import com.openexchange.config.ForcedReloadable;
 import com.openexchange.config.Reloadable;
 import com.openexchange.config.lean.LeanConfigurationService;
+import com.openexchange.database.CreateTableService;
+import com.openexchange.database.DatabaseService;
 import com.openexchange.filestore.FileStorageProvider;
 import com.openexchange.filestore.s3.internal.S3FileStorageFactory;
 import com.openexchange.filestore.s3.internal.client.S3ClientFactory;
+import com.openexchange.filestore.s3.internal.groupware.S3CreateTableService;
+import com.openexchange.filestore.s3.internal.groupware.S3CreateTableTask;
+import com.openexchange.filestore.s3.internal.groupware.S3DeleteListener;
 import com.openexchange.filestore.s3.internal.client.S3ClientRegistry;
 import com.openexchange.filestore.s3.metrics.S3FileStorageMetricCollector;
+import com.openexchange.groupware.delete.DeleteListener;
+import com.openexchange.groupware.update.DefaultUpdateTaskProviderService;
+import com.openexchange.groupware.update.UpdateTaskProviderService;
+import com.openexchange.net.ssl.SSLSocketFactoryProvider;
+import com.openexchange.net.ssl.config.SSLConfigurationService;
 import com.openexchange.osgi.HousekeepingActivator;
 
 /**
@@ -47,7 +58,7 @@ public class S3Activator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { LeanConfigurationService.class };
+        return new Class<?>[] { LeanConfigurationService.class, DatabaseService.class, SSLSocketFactoryProvider.class, SSLConfigurationService.class };
     }
 
     @Override
@@ -77,12 +88,17 @@ public class S3Activator extends HousekeepingActivator {
         //
         System.setProperty(com.amazonaws.services.s3.internal.SkipMd5CheckStrategy.DISABLE_GET_OBJECT_MD5_VALIDATION_PROPERTY, "true");
 
+        // Register update task, create table job and delete listener
+        registerService(CreateTableService.class, new S3CreateTableService());
+        registerService(UpdateTaskProviderService.class, new DefaultUpdateTaskProviderService(new S3CreateTableTask()));
+        registerService(DeleteListener.class, new S3DeleteListener());
+
         final LeanConfigurationService config = getService(LeanConfigurationService.class);
 
         // Enable service metric collection (overall byte throughput)
         AwsSdkMetrics.setMetricCollector(new S3FileStorageMetricCollector(config));
 
-        S3ClientRegistry registry = new S3ClientRegistry(new S3ClientFactory(), this);
+        S3ClientRegistry registry = new S3ClientRegistry(this);
         S3FileStorageFactory factory = new S3FileStorageFactory(registry, this);
         registerService(Reloadable.class, registry);
         registerService(FileStorageProvider.class, factory);
